print.survHE: Print a summary of the survival model(s) fitted by fit.models
Description
Prints the summary table for the model(s) fitted, with the estimate of the
parameters
Usage
# S3 method for survHE
print(x, mod = 1, ...)
Arguments
x
the survHE object (the output of the call to
fit.models)
mod
is the index of the model. Default value is 1, but the user can
choose which model fit to visualise, if the call to fit.models has a vector
argument for distr (so many models are fitted & stored in the same object)
...
additional options, including: digits = number of
significant digits to be shown in the summary table (default = 6)
original = a flag to say whether the original table
from either flexsurv or INLA or rstan should be printed
Author
Gianluca Baio
References
G Baio (2019). survHE: Survival analysis for health economic evaluation
and cost-effectiveness modelling. Journal of Statistical Software (2020). vol 95,
14, 1-47. doi:10.18637/jss.v095.i14