summary.survHE: Prints a summary table for the distribution the mean survival time for a
given model and data
Description
Calculates the mean survival time as the area under the survival curve
Usage
# S3 method for survHE
summary(object, mod = 1, t = NULL, nsim = 1000, ...)
Value
mean.surv
A matrix with the simulated values for the mean
survival times
tab
A summary table
Arguments
object
a survHE object (resulting from the call to
fit.models
mod
the model to be analysed (default = 1)
t
the vector of times to be used in the computation. Default = NULL,
which means the observed times will be used. NB: the vector of times should
be: i) long enough so that S(t) goes to 0; and ii) dense enough so that the
approximation to the AUC is sufficiently precise
nsim
the number of simulations from the survival curve distributions
to be used (to compute interval estimates)
...
Additional options
Author
Gianluca Baio
Details
A list comprising of the following elements
References
G Baio (2019). survHE: Survival analysis for health economic evaluation
and cost-effectiveness modelling. Journal of Statistical Software (2020). vol 95,
14, 1-47. doi:10.18637/jss.v095.i14